From 8cdb5c170a4f0983d40e98d0cbeb0d50939550db Mon Sep 17 00:00:00 2001
From: Zhiyong Yan <zhiyong.yan@windriver.com>
Date: Tue, 25 Apr 2023 11:35:52 +0800
Subject: [PATCH] arm: Install single-step software breakpoing

If resume_step is requested by GDB,
install single-step breakpoint, although the thread need keep pending.

Upstream-Status: Pending
Signed-off-by: Zhiyong Yan zhiyong.yan@windriver.com
---
 gdbserver/linux-low.cc | 12 ++++++++++--
 1 file changed, 10 insertions(+), 2 deletions(-)

diff --git a/gdbserver/linux-low.cc b/gdbserver/linux-low.cc
index e6a39202a98..543daf66376 100644
--- a/gdbserver/linux-low.cc
+++ b/gdbserver/linux-low.cc
@@ -4670,8 +4670,16 @@ linux_process_target::resume_one_thread (thread_info *thread,
 
       proceed_one_lwp (thread, NULL);
     }
-  else
-    threads_debug_printf ("leaving LWP %ld stopped", lwpid_of (thread));
+  else{
+	threads_debug_printf ("leaving LWP %ld stopped", lwpid_of (thread));
+	if(thread->last_resume_kind == resume_step){
+	    /*
+	    * If resume_step is required by GDB, install single-step breakpoint.
+	    */
+	    if (supports_software_single_step())
+	       install_software_single_step_breakpoints (lwp);
+	}
+  }
 
   thread->last_status.set_ignore ();
   lwp->resume = NULL;
-- 
2.25.1

